#!/bin/sh

STORE="/home/evert/Pictures/screenshots"
EMAIL="post@evert.net"

# -------------
# Makes screenshots, optionally mails them.
# Evert Mouw, 2019-12-27

DEPENDENCIES="scrot xclip xfce4-screenshooter notify-send mail"
for D in $DEPENDENCIES; do
	if ! which $D > /dev/null; then
		echo "$D not found"
		exit 1
	fi
done

if ! [ -d "$STORE" ]; then
	MSG="$STORE is not a directory."
	echo "$MSG"
	notify-send --icon=error "screenshooter" "$MSG"
	exit 1
fi

if ! [ -w "$STORE" ]; then
	MSG="$STORE is not writable!"
	echo "$MSG"
	notify-send --icon=error "screenshooter" "$MSG"
	exit 1
fi

FG=$(xdotool getwindowfocus getwindowname | tr -cs '\60-\71\101-\132\141-\172' '_' | cut -c 1-33)
ME="$(whoami)@$(hostname -s)"

case $1 in
region|select)
	OPTIONS="--select --freeze --line style=dash,width=3"
	OUTNAME="$STORE/%Y-%m-%dT%H.%M.%S_$FG.part"
	break
	;;
active|focused)
	OPTIONS="--focused --border"
	OUTNAME="$STORE/%Y-%m-%dT%H.%M.%S_$FG"
	break
	;;
fullscreen|full)
	OPTIONS="--multidisp"
	OUTNAME="$STORE/%Y-%m-%dT%H.%M.%S_$ME.full"
	break
	;;
custom)
	xfce4-screenshooter
	exit 0
	break
	;;
*)
	echo "Whut?"
	exit 1
esac

scrot $OPTIONS --exec 'xclip -selection clipboard -target image/png -in $f; echo -n "$f" | xclip -selection primary' "$OUTNAME.png"

if [ "$?" -ne "0" ]; then
	MSG="Some error occurred.\nOUTNAME=$OUTNAME\nACTION=$1"
	echo -e "$MSG"
	notify-send --icon=warn "screenshooter" "$MSG"
	exit 1
fi

OUTFILE=$(xclip -selection primary -out)
notify-send --icon=info "screenshooter" "Screenshot saved as $OUTFILE"

case $2 in
'')
	# silently ignore
	break
	;;
mail)
	echo "Screenshot" | mail -s screenshot -a "$OUTFILE" $EMAIL
	break
	;;
*)
	echo "2nd argument not recognized"
	exit 1
esac

